@@ -660,6 +660,12 @@ class LocalPorvider(BaseProvider):
             table_name: 'RPT_FORECAST_STK_TC'
         """
         return CDP.suntime_repofc_stk_tc(instruments,start_date,end_date)
+    
+    def suntime_earning_adj(self,instruments = None,start_date = None,end_date = None):
+        """
+            table_name: 'RPT_EARNINGS_ADJUST'
+        """
+        return CDP.suntime_earning_adj(instruments,start_date,end_date)
 
 
 TDP = getattr(daily,provider_config["TDP"])()
