@@ -41,6 +41,7 @@ suntime_confc_stk = os.path.join(data_path,r"CON_FORECAST_STK")
 suntime_confc_roll_stk = os.path.join(data_path,r"CON_FORECAST_ROLL_STK")
 suntime_repofc_stk = os.path.join(data_path,r"RPT_FORECAST_STK")
 suntime_repofc_stk_tc = os.path.join(data_path,r"RPT_FORECAST_STK_TC")
+suntime_earning_adj = os.path.join(data_path,r"RPT_EARNINGS_ADJUST")
 
 class BaseConsusDataProvider(abc.ABC):
 
@@ -75,6 +76,26 @@ class LoacalConsusProvider(BaseConsusDataProvider):
                     tgt_rp = [tgt_rp,]
                 data = data.loc[data[self.tidx[1]].isin(tgt_rp)]
             return data
+    
+    def get_cum_repo_data(self,datapath,instruments = None,fields = None,start_date = None,end_date = None):
+        df = pd.read_hdf(os.path.join(datapath,'all.h5'),"data")
+        if not instruments is None:
+            try:
+                df = df.loc[df.index.get_level_values("stockcode").isin(instruments)]
+            except KeyError:
+                print('Index %s info not found')
+                return pd.DataFrame()
+
+        if (start_date is not None) & (end_date is not None):
+            start_date,end_date = to_intdate(start_date),to_intdate(end_date)
+            dateindices=df.index.get_level_values("create_date")
+            df = df.loc[(dateindices <= end_date)&(dateindices >= start_date)]
+        
+        if not fields is None:
+            if isinstance(fields,str):
+                fields = [fields]
+            df = df[fields]
+        return df
         
     @print_func_time
     def consus(self,instruments,fields,foreward_type,window_days,**kws):
@@ -104,15 +125,10 @@ class LoacalConsusProvider(BaseConsusDataProvider):
         return self.get_repo_data(suntime_repofc_stk,instruments,fields,tidx = ["create_date"],**kws)
 
     @print_func_time
-    def suntime_repofc_stk_tc(self,instruments = None,start_date = None,end_date = None):
-        df = pd.read_hdf(os.path.join(suntime_repofc_stk_tc,'all.h5'),"data")
-        try:
-            df = df.loc[df.index.get_level_values["stockcode"].isin(instruments)]
-            if (start_date is not None) & (end_date is not None):
-                start_date,end_date = to_intdate(start_date),to_intdate(end_date)
-                dateindices=df.index.get_level_values["create_date"]
-                df = df.loc[(dateindices <= end_date)&(dateindices >= start_date)]
-            return df
-        except KeyError:
-            print('Index %s info not found')
-            return pd.DataFrame()
\ No newline at end of file
+    def suntime_repofc_stk_tc(self,instruments = None,fields = None, start_date = None,end_date = None):
+        return self.get_cum_repo_data(suntime_repofc_stk_tc,instruments,fields,start_date,end_date)
+    
+    @print_func_time
+    def suntime_earning_adj(self,instruments = None,fields = None,start_date = None,end_date = None):
+        return self.get_cum_repo_data(suntime_earning_adj,instruments,fields,start_date,end_date)
+            
\ No newline at end of file
