@@ -18,6 +18,8 @@ ashare_profit_noti = os.path.join(data_path,r'AShareProfitNotice')
 ashare_ttmhis = os.path.join(data_path,r'AShareTTMHis')
 ashare_holdernumber = os.path.join(data_path,r'AShareHolderNumber')
 ashare_insideholder =  os.path.join(data_path,r'AShareInsideHolder')
+ashare_holderdata =  os.path.join(data_path,r'AShareinstHolderDerData')
+ashare_managerewr = os.path.join(data_path,r'AShareManagementHoldReward')
 
 ashare_issuedate_pre = os.path.join(data_path,r'AShareIssuingDatePredict')
 ashare_fanc_indicator = os.path.join(data_path,r'AShareFinancialIndicator')
@@ -97,7 +99,15 @@ class LoacalFincReportsProvider(BaseFincReportsProvider):
 
     @print_func_time
     def repo_inside_holder(self,instruments,fields,**kws):
-        return self.get_repo_data(ashare_insideholder,instruments,fields,tidx = ["ann_date"],**kws) 
+        return self.get_repo_data(ashare_insideholder,instruments,fields,tidx = ["ann_date","report_period"],**kws) 
+
+    @print_func_time
+    def repo_holder_data(self,instruments,fields,**kws):
+        return self.get_repo_data(ashare_holderdata,instruments,fields,tidx = ["ann_date","report_period"],**kws) 
+
+    @print_func_time
+    def repo_manage_rewr(self,instruments,fields,**kws):
+        return self.get_repo_data(ashare_managerewr,instruments,fields,tidx = ["ann_date","end_date","manid"],**kws) 
 
     @print_func_time
     def repo_issuedate_pre(self,instruments,fields,**kws):
